var gulp = require('gulp');
var webpack = require('webpack');
var del = require('del');

function buildJS(mode, callback){

    //書き出し設定 =========
    var settings = {
        context: __dirname + '/htdocs/src',
        entry:'./js/hello.js',
        output: {
            path: 'htdocs/js',
            filename: 'main.js'
        },
        plugins:[]
    };
    //==============

    settings.module = {
        loaders: [
            {
                test: /\.js$/,
                exclude: /node_modules/,
                loader: "babel-loader"
            }
        ]
    };

    if(mode == "debug"){
        settings.devtool = 'source-map';
    }else if(mode == "release"){
        settings.plugins.push(
            new webpack.DefinePlugin({
                "process.env": { NODE_ENV: JSON.stringify("production") }
            }),
            new webpack.optimize.UglifyJsPlugin({
                compress: { warnings: false }
            })
        );
    }

    webpack(settings, function(err, stats){
        if(err){
            console.error('webpack fatal error', err);
            return;
        }
        var jsonStats = stats.toJson();
        if(jsonStats.errors.length > 0){
            console.error('bundle error');
            jsonStats.errors[0].split('\n').map(function(errLine){
                console.error(errLine);
            });
            return;
        }
        if(jsonStats.warnings.length > 0){
            console.log('bundle warning', jsonStats.warnings);
        }
        console.log('bundle complete');
        if(callback){
            callback();
        }
    })
}

/**
 * デバッグモード
 * js圧縮なし。React developmentモード。sourcemapあり
 */
gulp.task('bundle_debug', function(){
    buildJS("debug");
});

/**
 * リリースモード
 * js圧縮あり。React productionモード。sourcemapファイル削除
 */
gulp.task('bundle_release', function(){
    buildJS("release", function(){
        del('./htdocs/js/*.map');
    });
});
